@@ -2,7 +2,7 @@
 
 BigInt &BigInt::clearBit(size_t index)
 {
-    BN_clear_bit(&d_bn, index);
+    BN_clear_bit(d_bn, index);
     return *this;
 }
 
