@@ -3,7 +3,7 @@
 BigInt BigInt::divc(BigInt *remainder, BigInt const &rhs) const
 {
     BigInt ret(*this);
-    checked3(&ret.d_bn, &remainder->d_bn, rhs, "div");
+    checked3(ret.d_bn, remainder->d_bn, rhs, "div");
     return ret;
 }
 
