@@ -1,4 +1,4 @@
 inline bool BigInt::isZero() const
 {
-    return BN_is_zero(&d_bn);
+    return BN_is_zero(d_bn);
 }
