@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::subModc(BigInt const &rhs, BigInt const &mod) const
+BigInt BigInt::subModc(BigInt const &rhs, BigInt const &mod) const
 {
     BigInt ret(*this);
     ret.subMod(rhs, mod);
