@@ -1,8 +1,10 @@
 #include "encryptbuf.ih"
 
-void EncryptBufImp::setChar(char &ch, IRandStream &irs)
+// static
+void EncryptBuf::setChar(char &ch, IRandStream &irs)
 {
     int value;
     irs >> value;
     ch = value;
 }
+
