@@ -2,5 +2,5 @@
 
 string const &HMacBuf::hash() const
 {
-    return d_pimpl->digest;
+    return d_digest;
 }
