@@ -1,6 +1,6 @@
 #include "hostname.ih"
 
-Hostname::Hostname(string const &host) throw(Errno)
+Hostname::Hostname(string const &host)
 :
     Hostent(GetHostent::gethostent("Hostname::Hostname(std::string)", host))
 {
