@@ -3,8 +3,8 @@
 auto_ptr<Pipe> d_child_inp;          // cin read by the CHILD
 auto_ptr<Pipe> d_child_outp;         // cout written by the CHILD
 
-OFdStreambuf    d_childCinbuf; 
-IFdStreambuf    d_childCoutbuf;
+OFdBuf    d_childCinbuf; 
+IFdBuf    d_childCoutbuf;
 
 ostream   d_childCin(0);            // Parent inserts child cin
 istream   d_childCout(0);           // Parent extr. child cout
