@@ -13,7 +13,7 @@ void Process::parentRedirections()
 
         if (not (d_setMode & IN_PIPE))
         {
-            d_oChildInbuf.open(fd, 200);
+            d_oChildInbuf.reset(fd, 200);
             d_oChildIn.rdbuf(&d_oChildInbuf);
         }
     }
@@ -24,7 +24,7 @@ void Process::parentRedirections()
 
         if (not (d_setMode & OUT_PIPE))
         {
-            d_iChildOutbuf.open(fd, 200);
+            d_iChildOutbuf.reset(fd, 200);
             d_iChildOut.rdbuf(&d_iChildOutbuf);
             d_selector.addReadFd(fd);
         }
@@ -35,7 +35,7 @@ void Process::parentRedirections()
     if (d_mode & CERR)
     {
         int fd = d_iChildErrPipe.readOnly();
-        d_iChildErrbuf.open(fd, 200);
+        d_iChildErrbuf.reset(fd, 200);
         d_iChildErr.rdbuf(&d_iChildErrbuf);
         d_selector.addReadFd(fd);
     }
