@@ -7,9 +7,9 @@ int Process::stop()
 
     d_oChildIn.flush();
 
-    d_oChildInbuf.open(-1);
-    d_iChildOutbuf.open(-1);
-    d_iChildErrbuf.open(-1);
+    d_oChildInbuf.reset(-1);
+    d_iChildOutbuf.reset(-1);
+    d_iChildErrbuf.reset(-1);
 
     closeWriteFd(d_oChildInPipe);
     closeReadFd(d_iChildOutPipe);
@@ -17,7 +17,7 @@ int Process::stop()
 
     discontinue(d_child);
 
-    d_data->d_limit.join();
+    d_limit.join();
 
     d_active = false;
 
