@@ -4,7 +4,6 @@ ReadLineBuf::ReadLineBuf(string const &prompt, size_t historySize, Type type)
 :
     d_history(historySize > 0),
     d_prompt(prompt),
-    d_buffer(0),
     d_readline(&ReadLineBuf::readLine),
     d_timestamp(0)
 {
@@ -18,6 +17,11 @@ ReadLineBuf::ReadLineBuf(string const &prompt, size_t historySize, Type type)
         if (type == EXPAND_HISTORY)
             d_readline = &ReadLineBuf::expandLine;
         using_history();
-        stifle_history(historySize > INT_MAX ? INT_MAX : historySize);
+        stifle_history(
+            historySize > static_cast<size_t>(numeric_limits<int>::max()) ? 
+                numeric_limits<int>::max() 
+                    : 
+                historySize
+        );
     }
 }
