@@ -1,6 +1,9 @@
 #include "readlinehistory.ih"
 
-istream &FBB::operator>>(istream &in, ReadLineHistory &history)
+namespace FBB
+{
+
+std::istream &operator>>(std::istream &in, ReadLineHistory &history)
 {
     if (!in)
         return in;
@@ -12,3 +15,5 @@ istream &FBB::operator>>(istream &in, ReadLineHistory &history)
 
     return history.extractLines(in);
 }
+
+}
