@@ -2,7 +2,7 @@
 
 TableSupport &TableSupport::operator=(TableSupport &&tmp)
 {
-    fswap(*this, tmp);
+    fswap(*this, tmp, d_elements);
     return *this;
 }
 
