@@ -3,9 +3,9 @@
 TableSupport::TableSupport()
 :
     d_streamPtr(0),
-    d_rows(0),
-    d_colWidth(0),
-    d_maxWidth(0),
+    d_nRows(0),
+    d_nColumns(0),
+    d_align(0),
     d_tableWidth(0)
 {}
 
